@@ -37,9 +37,11 @@
 #include <assert.h>
 #include <format.h>
 #include <main.h>
+#include <rust/cxx.h>
 #include <shared.h>
 #include <stdlib.h>
 #include <string.h>
+#include <taskchampion-cpp/lib.h>
 #include <unistd.h>
 
 #include <algorithm>
@@ -125,7 +127,6 @@ std::string configurationDefaults =
     "dependency.indicator=D                         # What to show as a dependency indicator\n"
     "recurrence.indicator=R                         # What to show as a task recurrence indicator\n"
     "recurrence.limit=1                             # Number of future recurring pending tasks\n"
-    "undo.style=side                                # Undo style - can be 'side', or 'diff'\n"
     "regex=1                                        # Assume all search/filter strings are "
     "regexes\n"
     "xterm.title=0                                  # Sets xterm title for some commands\n"
@@ -317,6 +318,12 @@ std::string configurationDefaults =
     "#sync.server.client_id                         # Client ID for sync to a server\n"
     "#sync.server.url                               # URL of the sync server\n"
     "#sync.local.server_dir                         # Directory for local sync\n"
+    "#sync.aws.region                               # region for AWS sync\n"
+    "#sync.aws.bucket                               # bucket for AWS sync\n"
+    "#sync.aws.access_key_id                        # access_key_id for AWS sync\n"
+    "#sync.aws.secret_access_key                    # secret_access_key for AWS sync\n"
+    "#sync.aws.profile                              # profile name for AWS sync\n"
+    "#sync.aws.default_credentials                  # use default credentials for AWS sync\n"
     "#sync.gcp.credential_path                      # Path to JSON file containing credentials to "
     "authenticate GCP Sync\n"
     "#sync.gcp.bucket                               # Bucket for sync to GCP\n"
@@ -681,6 +688,11 @@ int Context::initialize(int argc, const char** argv) {
     rc = 2;
   }
 
+  catch (rust::Error& err) {
+    error(err.what());
+    rc = 2;
+  }
+
   catch (int) {
     // Hooks can terminate processing by throwing integers.
     rc = 4;
@@ -689,7 +701,7 @@ int Context::initialize(int argc, const char** argv) {
   catch (const std::regex_error& e) {
     std::cout << "regex_error caught: " << e.what() << '\n';
   } catch (...) {
-    error("knknown error. Please report.");
+    error("Unknown error. Please report.");
     rc = 3;
   }
 
@@ -772,6 +784,11 @@ int Context::run() {
     rc = 2;
   }
 
+  catch (rust::Error& err) {
+    error(err.what());
+    rc = 2;
+  }
+
   catch (int) {
     // Hooks can terminate processing by throwing integers.
     rc = 4;
@@ -1093,6 +1110,11 @@ void Context::staticInitialization() {
   Task::regex = Variant::searchUsingRegex = config.getBoolean("regex");
   Lexer::dateFormat = Variant::dateFormat = config.get("dateformat");
 
+  auto weekStart = Datetime::dayOfWeek(config.get("weekstart"));
+  if (weekStart != 0 && weekStart != 1)
+    throw std::string(
+        "The 'weekstart' configuration variable may only contain 'Sunday' or 'Monday'.");
+  Datetime::weekstart = weekStart;
   Datetime::isoEnabled = config.getBoolean("date.iso");
   Datetime::standaloneDateEnabled = false;
   Datetime::standaloneTimeEnabled = false;
@@ -1155,6 +1177,7 @@ void Context::createDefaultConfig() {
              << "\n# Color theme (uncomment one to use)\n"
              << "#include light-16.theme\n"
              << "#include light-256.theme\n"
+             << "#include bubblegum-256.theme\n"
              << "#include dark-16.theme\n"
              << "#include dark-256.theme\n"
              << "#include dark-red-256.theme\n"
