@@ -138,7 +138,7 @@ Task::Task(const json::object* obj) {
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-Task::Task(tc::Task obj) {
+Task::Task(rust::Box<tc::TaskData> obj) {
   id = 0;
   urgency_value = 0.0;
   recalc_urgency = true;
@@ -146,7 +146,7 @@ Task::Task(tc::Task obj) {
   is_blocking = false;
   annotation_count = 0;
 
-  parseTC(obj);
+  parseTC(std::move(obj));
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -717,8 +717,12 @@ void Task::parseJSON(const json::object* root_obj) {
 
 ////////////////////////////////////////////////////////////////////////////////
 // Note that all fields undergo encode/decode.
-void Task::parseTC(const tc::Task& task) {
-  data = task.get_taskmap();
+void Task::parseTC(rust::Box<tc::TaskData> task) {
+  auto items = task->items();
+  data.clear();
+  for (auto& item : items) {
+    data[static_cast<std::string>(item.prop)] = static_cast<std::string>(item.value);
+  }
 
   // count annotations
   annotation_count = 0;
@@ -728,11 +732,8 @@ void Task::parseTC(const tc::Task& task) {
     }
   }
 
-  data["uuid"] = task.get_uuid();
+  data["uuid"] = static_cast<std::string>(task->get_uuid().to_string());
   id = Context::getContext().tdb2.id(data["uuid"]);
-
-  is_blocking = task.is_blocking();
-  is_blocked = task.is_blocked();
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -1242,14 +1243,14 @@ void Task::fixTagsAttribute() {
 bool Task::isTagAttr(const std::string& attr) { return attr.compare(0, 4, "tag_") == 0; }
 
 ////////////////////////////////////////////////////////////////////////////////
-const std::string Task::tag2Attr(const std::string& tag) const {
+std::string Task::tag2Attr(const std::string& tag) {
   std::stringstream tag_attr;
   tag_attr << "tag_" << tag;
   return tag_attr.str();
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-const std::string Task::attr2Tag(const std::string& attr) const {
+std::string Task::attr2Tag(const std::string& attr) {
   assert(isTagAttr(attr));
   return attr.substr(4);
 }
@@ -1270,14 +1271,14 @@ void Task::fixDependsAttribute() {
 bool Task::isDepAttr(const std::string& attr) { return attr.compare(0, 4, "dep_") == 0; }
 
 ////////////////////////////////////////////////////////////////////////////////
-const std::string Task::dep2Attr(const std::string& tag) const {
+std::string Task::dep2Attr(const std::string& tag) {
   std::stringstream tag_attr;
   tag_attr << "dep_" << tag;
   return tag_attr.str();
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-const std::string Task::attr2Dep(const std::string& attr) const {
+std::string Task::attr2Dep(const std::string& attr) {
   assert(isDepAttr(attr));
   return attr.substr(4);
 }
@@ -1407,13 +1408,29 @@ void Task::substitute(const std::string& from, const std::string& to, const std:
 }
 #endif
 
+////////////////////////////////////////////////////////////////////////////////
+// Validate a task for addition, raising user-visible errors for inconsistent or
+// incorrect inputs. This is called before `Task::validate`.
+void Task::validate_add() {
+  // There is no fixing a missing description.
+  if (!has("description"))
+    throw std::string("A task must have a description.");
+  else if (get("description") == "")
+    throw std::string("Cannot add a task that is blank.");
+
+  // Cannot have an old-style recur frequency with no due date - when would it recur?
+  if (has("recur") && (!has("due") || get("due") == ""))
+    throw std::string("A recurring task must also have a 'due' date.");
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 // The purpose of Task::validate is three-fold:
 //   1) To provide missing attributes where possible
 //   2) To provide suitable warnings about odd states
-//   3) To generate errors when the inconsistencies are not fixable
-//   4) To update status depending on other attributes
+//   3) To update status depending on other attributes
 //
+// As required by TaskChampion, no combination of properties and values is an
+// error. This function will try to make sensible defaults and resolve inconsistencies.
 // Critically, note that despite the name this is not a read-only function.
 //
 void Task::validate(bool applyDefault /* = true */) {
@@ -1427,6 +1444,8 @@ void Task::validate(bool applyDefault /* = true */) {
     Lexer lex(uid);
     std::string token;
     Lexer::Type type;
+    // `uuid` is not a property in the TaskChampion model, so an invalid UUID is
+    // actually an error.
     if (!lex.isUUID(token, type, true)) throw format("Not a valid UUID '{1}'.", uid);
   } else
     set("uuid", uuid());
@@ -1542,27 +1561,27 @@ void Task::validate(bool applyDefault /* = true */) {
   validate_before("scheduled", "due");
   validate_before("scheduled", "end");
 
-  // 3) To generate errors when the inconsistencies are not fixable
+  if (!has("description") || get("description") == "")
+    Context::getContext().footnote(format("Warning: task has no description."));
 
-  // There is no fixing a missing description.
-  if (!has("description"))
-    throw std::string("A task must have a description.");
-  else if (get("description") == "")
-    throw std::string("Cannot add a task that is blank.");
+  // Cannot have an old-style recur frequency with no due date - when would it recur?
+  if (has("recur") && (!has("due") || get("due") == "")) {
+    Context::getContext().footnote(format("Warning: recurring task has no due date."));
+    remove("recur");
+  }
 
-  // Cannot have a recur frequency with no due date - when would it recur?
-  if (has("recur") && (!has("due") || get("due") == ""))
-    throw std::string("A recurring task must also have a 'due' date.");
-
-  // Recur durations must be valid.
+  // Old-style recur durations must be valid.
   if (has("recur")) {
     std::string value = get("recur");
     if (value != "") {
       Duration p;
       std::string::size_type i = 0;
-      if (!p.parse(value, i))
+      if (!p.parse(value, i)) {
         // TODO Ideal location to map unsupported old recurrence periods to supported values.
-        throw format("The recurrence value '{1}' is not valid.", value);
+        Context::getContext().footnote(
+            format("Warning: The recurrence value '{1}' is not valid.", value));
+        remove("recur");
+      }
     }
   }
 }
@@ -1602,40 +1621,6 @@ const std::string Task::decode(const std::string& value) const {
   return str_replace(modified, "&close;", "]");
 }
 
-////////////////////////////////////////////////////////////////////////////////
-tc::Status Task::status2tc(const Task::status status) {
-  switch (status) {
-    case Task::pending:
-      return tc::Status::Pending;
-    case Task::completed:
-      return tc::Status::Completed;
-    case Task::deleted:
-      return tc::Status::Deleted;
-    case Task::waiting:
-      return tc::Status::Pending;  // waiting is no longer a status
-    case Task::recurring:
-      return tc::Status::Recurring;
-    default:
-      return tc::Status::Unknown;
-  }
-}
-
-////////////////////////////////////////////////////////////////////////////////
-Task::status Task::tc2status(const tc::Status status) {
-  switch (status) {
-    case tc::Status::Pending:
-      return Task::pending;
-    case tc::Status::Completed:
-      return Task::completed;
-    case tc::Status::Deleted:
-      return Task::deleted;
-    case tc::Status::Recurring:
-      return Task::recurring;
-    default:
-      return Task::pending;
-  }
-}
-
 ////////////////////////////////////////////////////////////////////////////////
 int Task::determineVersion(const std::string& line) {
   // Version 2 looks like:
@@ -2167,274 +2152,3 @@ std::string Task::diff(const Task& after) const {
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-// Similar to diff, but formatted for inclusion in the output of the info command
-std::string Task::diffForInfo(const Task& after, const std::string& dateformat,
-                              long& last_timestamp, const long current_timestamp) const {
-  // Attributes are all there is, so figure the different attribute names
-  // between before and after.
-  std::vector<std::string> beforeAtts;
-  for (auto& att : data) beforeAtts.push_back(att.first);
-
-  std::vector<std::string> afterAtts;
-  for (auto& att : after.data) afterAtts.push_back(att.first);
-
-  std::vector<std::string> beforeOnly;
-  std::vector<std::string> afterOnly;
-  listDiff(beforeAtts, afterAtts, beforeOnly, afterOnly);
-
-  // Now start generating a description of the differences.
-  std::stringstream out;
-  for (auto& name : beforeOnly) {
-    if (isAnnotationAttr(name)) {
-      out << format("Annotation '{1}' deleted.\n", get(name));
-    } else if (isTagAttr(name)) {
-      out << format("Tag '{1}' deleted.\n", attr2Tag(name));
-    } else if (isDepAttr(name)) {
-      out << format("Dependency on '{1}' deleted.\n", attr2Dep(name));
-    } else if (name == "depends" || name == "tags") {
-      // do nothing for legacy attributes
-    } else if (name == "start") {
-      Datetime started(get("start"));
-      Datetime stopped;
-
-      if (after.has("end"))
-        // Task was marked as finished, use end time
-        stopped = Datetime(after.get("end"));
-      else
-        // Start attribute was removed, use modification time
-        stopped = Datetime(current_timestamp);
-
-      out << format("{1} deleted (duration: {2}).", Lexer::ucFirst(name),
-                    Duration(stopped - started).format())
-          << "\n";
-    } else {
-      out << format("{1} deleted.\n", Lexer::ucFirst(name));
-    }
-  }
-
-  for (auto& name : afterOnly) {
-    if (isAnnotationAttr(name)) {
-      out << format("Annotation of '{1}' added.\n", after.get(name));
-    } else if (isTagAttr(name)) {
-      out << format("Tag '{1}' added.\n", attr2Tag(name));
-    } else if (isDepAttr(name)) {
-      out << format("Dependency on '{1}' added.\n", attr2Dep(name));
-    } else if (name == "depends" || name == "tags") {
-      // do nothing for legacy attributes
-    } else {
-      if (name == "start") last_timestamp = current_timestamp;
-
-      out << format("{1} set to '{2}'.", Lexer::ucFirst(name),
-                    renderAttribute(name, after.get(name), dateformat))
-          << "\n";
-    }
-  }
-
-  for (auto& name : beforeAtts)
-    if (name != "uuid" && name != "modified" && get(name) != after.get(name) && get(name) != "" &&
-        after.get(name) != "") {
-      if (name == "depends" || name == "tags") {
-        // do nothing for legacy attributes
-      } else if (isTagAttr(name) || isDepAttr(name)) {
-        // ignore new attributes
-      } else if (isAnnotationAttr(name)) {
-        out << format("Annotation changed to '{1}'.\n", after.get(name));
-      } else
-        out << format("{1} changed from '{2}' to '{3}'.", Lexer::ucFirst(name),
-                      renderAttribute(name, get(name), dateformat),
-                      renderAttribute(name, after.get(name), dateformat))
-            << "\n";
-    }
-
-  // Shouldn't just say nothing.
-  if (out.str().length() == 0) out << "No changes made.\n";
-
-  return out.str();
-}
-
-////////////////////////////////////////////////////////////////////////////////
-// Similar to diff, but formatted as a side-by-side table for an Undo preview
-Table Task::diffForUndoSide(const Task& after) const {
-  // Set the colors.
-  Color color_red(
-      Context::getContext().color() ? Context::getContext().config.get("color.undo.before") : "");
-  Color color_green(
-      Context::getContext().color() ? Context::getContext().config.get("color.undo.after") : "");
-
-  // Attributes are all there is, so figure the different attribute names
-  // between before and after.
-  Table view;
-  view.width(Context::getContext().getWidth());
-  view.intraPadding(2);
-  view.add("");
-  view.add("Prior Values");
-  view.add("Current Values");
-  setHeaderUnderline(view);
-
-  if (!is_empty()) {
-    const Task& before = *this;
-
-    std::vector<std::string> beforeAtts;
-    for (auto& att : before.data) beforeAtts.push_back(att.first);
-
-    std::vector<std::string> afterAtts;
-    for (auto& att : after.data) afterAtts.push_back(att.first);
-
-    std::vector<std::string> beforeOnly;
-    std::vector<std::string> afterOnly;
-    listDiff(beforeAtts, afterAtts, beforeOnly, afterOnly);
-
-    int row;
-    for (auto& name : beforeOnly) {
-      row = view.addRow();
-      view.set(row, 0, name);
-      view.set(row, 1, renderAttribute(name, before.get(name)), color_red);
-    }
-
-    for (auto& att : before.data) {
-      std::string priorValue = before.get(att.first);
-      std::string currentValue = after.get(att.first);
-
-      if (currentValue != "") {
-        row = view.addRow();
-        view.set(row, 0, att.first);
-        view.set(row, 1, renderAttribute(att.first, priorValue),
-                 (priorValue != currentValue ? color_red : Color()));
-        view.set(row, 2, renderAttribute(att.first, currentValue),
-                 (priorValue != currentValue ? color_green : Color()));
-      }
-    }
-
-    for (auto& name : afterOnly) {
-      row = view.addRow();
-      view.set(row, 0, name);
-      view.set(row, 2, renderAttribute(name, after.get(name)), color_green);
-    }
-  } else {
-    int row;
-    for (auto& att : after.data) {
-      row = view.addRow();
-      view.set(row, 0, att.first);
-      view.set(row, 2, renderAttribute(att.first, after.get(att.first)), color_green);
-    }
-  }
-
-  return view;
-}
-
-////////////////////////////////////////////////////////////////////////////////
-// Similar to diff, but formatted as a diff for an Undo preview
-Table Task::diffForUndoPatch(const Task& after, const Datetime& lastChange) const {
-  // This style looks like this:
-  //  --- before    2009-07-04 00:00:25.000000000 +0200
-  //  +++ after    2009-07-04 00:00:45.000000000 +0200
-  //
-  // - name: old           // att deleted
-  // + name:
-  //
-  // - name: old           // att changed
-  // + name: new
-  //
-  // - name:
-  // + name: new           // att added
-  //
-
-  // Set the colors.
-  Color color_red(
-      Context::getContext().color() ? Context::getContext().config.get("color.undo.before") : "");
-  Color color_green(
-      Context::getContext().color() ? Context::getContext().config.get("color.undo.after") : "");
-
-  const Task& before = *this;
-
-  // Generate table header.
-  Table view;
-  view.width(Context::getContext().getWidth());
-  view.intraPadding(2);
-  view.add("");
-  view.add("");
-
-  int row = view.addRow();
-  view.set(row, 0, "--- previous state", color_red);
-  view.set(row, 1, "Undo will restore this state", color_red);
-
-  row = view.addRow();
-  view.set(row, 0, "+++ current state ", color_green);
-  view.set(row, 1,
-           format("Change made {1}",
-                  lastChange.toString(Context::getContext().config.get("dateformat"))),
-           color_green);
-
-  view.addRow();
-
-  // Add rows to table showing diffs.
-  std::vector<std::string> all = Context::getContext().getColumns();
-
-  // Now factor in the annotation attributes.
-  for (auto& it : before.data)
-    if (it.first.substr(0, 11) == "annotation_") all.push_back(it.first);
-
-  for (auto& it : after.data)
-    if (it.first.substr(0, 11) == "annotation_") all.push_back(it.first);
-
-  // Now render all the attributes.
-  std::sort(all.begin(), all.end());
-
-  std::string before_att;
-  std::string after_att;
-  std::string last_att;
-  for (auto& a : all) {
-    if (a != last_att)  // Skip duplicates.
-    {
-      last_att = a;
-
-      before_att = before.get(a);
-      after_att = after.get(a);
-
-      // Don't report different uuid.
-      // Show nothing if values are the unchanged.
-      if (a == "uuid" || before_att == after_att) {
-        // Show nothing - no point displaying that which did not change.
-
-        // row = view.addRow ();
-        // view.set (row, 0, *a + ":");
-        // view.set (row, 1, before_att);
-      }
-
-      // Attribute deleted.
-      else if (before_att != "" && after_att == "") {
-        row = view.addRow();
-        view.set(row, 0, '-' + a + ':', color_red);
-        view.set(row, 1, before_att, color_red);
-
-        row = view.addRow();
-        view.set(row, 0, '+' + a + ':', color_green);
-      }
-
-      // Attribute added.
-      else if (before_att == "" && after_att != "") {
-        row = view.addRow();
-        view.set(row, 0, '-' + a + ':', color_red);
-
-        row = view.addRow();
-        view.set(row, 0, '+' + a + ':', color_green);
-        view.set(row, 1, after_att, color_green);
-      }
-
-      // Attribute changed.
-      else {
-        row = view.addRow();
-        view.set(row, 0, '-' + a + ':', color_red);
-        view.set(row, 1, before_att, color_red);
-
-        row = view.addRow();
-        view.set(row, 0, '+' + a + ':', color_green);
-        view.set(row, 1, after_att, color_green);
-      }
-    }
-  }
-
-  return view;
-}
-
-////////////////////////////////////////////////////////////////////////////////
