@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 //
-// Copyright 2006 - 2020, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2021, Tomas Babej, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,64 +25,63 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #include <cmake.h>
+// cmake.h include header must come first
+
 #include <CmdAdd.h>
 #include <Context.h>
 #include <format.h>
 #include <main.h>
 
 ////////////////////////////////////////////////////////////////////////////////
-CmdAdd::CmdAdd ()
-{
-  _keyword               = "add";
-  _usage                 = "task          add <mods>";
-  _description           = "Adds a new task";
-  _read_only             = false;
-  _displays_id           = false;
-  _needs_gc              = false;
-  _uses_context          = false;
-  _accepts_filter        = false;
+CmdAdd::CmdAdd() {
+  _keyword = "add";
+  _usage = "task          add <mods>";
+  _description = "Adds a new task";
+  _read_only = false;
+  _displays_id = false;
+  _needs_gc = false;
+  _uses_context = true;
+  _accepts_filter = false;
   _accepts_modifications = true;
   _accepts_miscellaneous = false;
-  _category              = Command::Category::operation;
+  _category = Command::Category::operation;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-int CmdAdd::execute (std::string& output)
-{
+int CmdAdd::execute(std::string& output) {
   // Apply the command line modifications to the new task.
   Task task;
-  task.modify (Task::modReplace, true);
-  Context::getContext ().tdb2.add (task);
+
+  // the task is empty, but DOM references can refer to earlier parts of the
+  // command line, e.g., `task add due:20110101 wait:due`.
+  task.modify(Task::modReplace, true);
+  Context::getContext().tdb2.add(task);
 
   // Do not display ID 0, users cannot query by that
-  auto status = task.getStatus ();
+  auto status = task.getStatus();
 
   // We may have a situation where both new-id and new-uuid config
   // variables are set. In that case, we'll show the new-uuid, as
   // it's enduring and never changes, and it's unlikely the caller
   // asked for this if they just wanted a human-friendly number.
 
-  if (Context::getContext ().verbose ("new-uuid") &&
-           status == Task::recurring)
-    output += format ("Created task {1} (recurrence template).\n", task.get ("uuid"));
+  if (Context::getContext().verbose("new-uuid") && status == Task::recurring)
+    output += format("Created task {1} (recurrence template).\n", task.get("uuid"));
 
-  else if (Context::getContext ().verbose ("new-uuid") ||
-          (Context::getContext ().verbose ("new-id") &&
-            (status == Task::completed ||
-             status == Task::deleted)))
-    output += format ("Created task {1}.\n", task.get ("uuid"));
+  else if (Context::getContext().verbose("new-uuid") ||
+           (Context::getContext().verbose("new-id") &&
+            (status == Task::completed || status == Task::deleted)))
+    output += format("Created task {1}.\n", task.get("uuid"));
 
-  else if (Context::getContext ().verbose ("new-id") &&
-      (status == Task::pending ||
-       status == Task::waiting))
-    output += format ("Created task {1}.\n", task.id);
+  else if (Context::getContext().verbose("new-id") &&
+           (status == Task::pending || status == Task::waiting))
+    output += format("Created task {1}.\n", task.id);
 
-  else if (Context::getContext ().verbose ("new-id") &&
-           status == Task::recurring)
-    output += format ("Created task {1} (recurrence template).\n", task.id);
+  else if (Context::getContext().verbose("new-id") && status == Task::recurring)
+    output += format("Created task {1} (recurrence template).\n", task.id);
 
-  if (Context::getContext ().verbose ("project"))
-    Context::getContext ().footnote (onProjectChange (task));
+  if (Context::getContext().verbose("project"))
+    Context::getContext().footnote(onProjectChange(task));
 
   return 0;
 }
