@@ -28,6 +28,7 @@
 // cmake.h include header must come first
 
 #include <CmdCustom.h>
+#include <CmdNews.h>
 #include <Context.h>
 #include <Filter.h>
 #include <Lexer.h>
@@ -222,11 +223,9 @@ int CmdCustom::execute(std::string& output) {
   }
 
   // Inform user about the new release highlights if not presented yet
-  Version news_version(Context::getContext().config.get("news.version"));
-  Version current_version = Version::Current();
-  auto should_nag = news_version != current_version && Context::getContext().verbose("news");
-  if (should_nag) {
+  if (CmdNews::should_nag()) {
     std::ostringstream notice;
+    Version current_version = Version::Current();
     notice << "Recently upgraded to " << current_version
            << ". "
               "Please run 'task news' to read highlights about the new release.";
@@ -242,7 +241,8 @@ int CmdCustom::execute(std::string& output) {
     Color warning = Color(Context::getContext().config.get("color.warning"));
     std::cerr << warning.colorize(format("Found existing '*.data' files in {1}", location)) << "\n";
     std::cerr << "  Taskwarrior's storage format changed in 3.0, requiring a manual migration.\n";
-    std::cerr << "  See https://github.com/GothenburgBitFactory/taskwarrior/releases.\n";
+    std::cerr << "  See https://taskwarrior.org/docs/upgrade-3/. Run `task import-v2` to import\n";
+    std::cerr << "  the tasks into the Taskwarrior-3.x format\n";
   }
 
   feedback_backlog();
