@@ -1,7 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
-// taskwarrior - a command line task list manager.
 //
-// Copyright 2006-2013, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2021, Tomas Babej, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -21,59 +20,55 @@
 // OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// http://www.opensource.org/licenses/mit-license.php
+// https://www.opensource.org/licenses/mit-license.php
 //
 ////////////////////////////////////////////////////////////////////////////////
 
-#define L10N                                           // Localization complete.
+#include <cmake.h>
+// cmake.h include header must come first
 
-#include <Context.h>
-#include <text.h>
-#include <i18n.h>
-#include <util.h>
-#include <main.h>
 #include <CmdLog.h>
-
-extern Context context;
+#include <Context.h>
+#include <format.h>
+#include <main.h>
 
 ////////////////////////////////////////////////////////////////////////////////
-CmdLog::CmdLog ()
-{
-  _keyword     = "log";
-  _usage       = "task          log <mods>";
-  _description = STRING_CMD_LOG_USAGE;
-  _read_only   = false;
+CmdLog::CmdLog() {
+  _keyword = "log";
+  _usage = "task          log <mods>";
+  _description = "Adds a new task that is already completed";
+  _read_only = false;
   _displays_id = false;
+  _needs_gc = false;
+  _uses_context = true;
+  _accepts_filter = false;
+  _accepts_modifications = true;
+  _accepts_miscellaneous = false;
+  _category = Command::Category::operation;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-int CmdLog::execute (std::string& output)
-{
-  int rc = 0;
-
+int CmdLog::execute(std::string& output) {
   // Apply the command line modifications to the new task.
-  A3 modifications = context.a3.extract_modifications ();
   Task task;
-  modify_task_description_replace (task, modifications);
-  task.setStatus (Task::completed);
+  task.modify(Task::modReplace, true);
+  task.setStatus(Task::completed);
 
-  // Recurring tasks get a special status.
-  if (task.has ("recur"))
-    throw std::string (STRING_CMD_LOG_NO_RECUR);
+  // Cannot log recurring tasks.
+  if (task.has("recur")) throw std::string("You cannot log recurring tasks.");
 
-  if (task.has ("wait"))
-    throw std::string (STRING_CMD_LOG_NO_WAITING);
+  // Cannot log waiting tasks.
+  if (task.has("wait")) throw std::string("You cannot log waiting tasks.");
 
-  context.tdb2.add (task);
-  if (context.verbose ("project"))
-    context.footnote (onProjectChange (task));
-  context.tdb2.commit ();
+  Context::getContext().tdb2.add(task);
 
-  if (context.verbose ("affected") ||
-      context.config.getBoolean ("echo.command")) // Deprecated 2.0
-    output = std::string (STRING_CMD_LOG_LOGGED) + "\n";
+  if (Context::getContext().verbose("project"))
+    Context::getContext().footnote(onProjectChange(task));
 
-  return rc;
+  if (Context::getContext().verbose("new-uuid"))
+    output = format("Logged task {1}.\n", task.get("uuid"));
+
+  return 0;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
