@@ -158,6 +158,8 @@ std::vector<NewsItem> NewsItem::all() {
   version2_6_0(items);
   version3_0_0(items);
   version3_1_0(items);
+  version3_2_0(items);
+  version3_3_0(items);
   return items;
 }
 
@@ -500,6 +502,34 @@ void NewsItem::version3_1_0(std::vector<NewsItem>& items) {
   items.push_back(news);
 }
 
+void NewsItem::version3_2_0(std::vector<NewsItem>& items) {
+  Version version("3.2.0");
+  NewsItem info{
+      version,
+      /*title=*/"`task info` Journal Restored",
+      /*bg_title=*/"",
+      /*background=*/"",
+      /*punchline=*/"",
+      /*update=*/
+      "Support for the \"journal\" output in `task info` has been restored. The command now\n"
+      "displays a list of changes made to the task, with timestamps.\n\n"};
+  items.push_back(info);
+}
+
+void NewsItem::version3_3_0(std::vector<NewsItem>& items) {
+  Version version("3.3.0");
+  NewsItem info{
+      version,
+      /*title=*/"AWS S3 Sync",
+      /*bg_title=*/"",
+      /*background=*/"",
+      /*punchline=*/"Use an AWS S3 bucket to sync Taskwarrior",
+      /*update=*/
+      "Taskwarrior now supports AWS as a backend for sync, in addition to existing support\n"
+      "for GCP and taskchampion-sync-server. See `man task-sync` for details.\n\n"};
+  items.push_back(info);
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 int CmdNews::execute(std::string& output) {
   auto words = Context::getContext().cli2.getWords();
@@ -600,3 +630,28 @@ int CmdNews::execute(std::string& output) {
 
   return 0;
 }
+
+bool CmdNews::should_nag() {
+  if (!Context::getContext().verbose("news")) {
+    return false;
+  }
+
+  Version news_version(Context::getContext().config.get("news.version"));
+  if (!news_version.is_valid()) news_version = Version("2.6.0");
+
+  Version current_version = Version::Current();
+
+  if (news_version == current_version) {
+    return true;
+  }
+
+  // Check if there are actually any interesting news items to show.
+  std::vector<NewsItem> items = NewsItem::all();
+  for (auto& item : items) {
+    if (item._version > news_version) {
+      return true;
+    }
+  }
+
+  return false;
+}
