@@ -51,6 +51,8 @@ class NewsItem {
   static void version2_6_0(std::vector<NewsItem>&);
   static void version3_0_0(std::vector<NewsItem>&);
   static void version3_1_0(std::vector<NewsItem>&);
+  static void version3_2_0(std::vector<NewsItem>&);
+  static void version3_3_0(std::vector<NewsItem>&);
 
  private:
   NewsItem(Version, const std::string&, const std::string& = "", const std::string& = "",
@@ -62,6 +64,8 @@ class CmdNews : public Command {
  public:
   CmdNews();
   int execute(std::string&);
+
+  static bool should_nag();
 };
 
 #endif
