@@ -194,15 +194,20 @@ int CmdShow::execute(std::string& output) {
       " search.case.sensitive"
       " sugar"
       " summary.all.projects"
-      " sync.local.server_dir"
+      " sync.aws.access_key_id"
+      " sync.aws.bucket"
+      " sync.aws.default_credentials"
+      " sync.aws.profile"
+      " sync.aws.region"
+      " sync.aws.secret_access_key"
       " sync.gcp.credential_path"
       " sync.gcp.bucket"
+      " sync.local.server_dir"
       " sync.server.client_id"
       " sync.encryption_secret"
       " sync.server.url"
       " sync.server.origin"
       " tag.indicator"
-      " undo.style"
       " urgency.active.coefficient"
       " urgency.scheduled.coefficient"
       " urgency.annotations.coefficient"
