@@ -35,12 +35,12 @@
 #include <inttypes.h>
 #include <shared.h>
 #include <signal.h>
+#include <taskchampion-cpp/lib.h>
 #include <util.h>
 
+#include <iostream>
 #include <sstream>
 
-#include "tc/Server.h"
-
 ////////////////////////////////////////////////////////////////////////////////
 CmdSync::CmdSync() {
   _keyword = "synchronize";
@@ -60,55 +60,99 @@ CmdSync::CmdSync() {
 int CmdSync::execute(std::string& output) {
   int status = 0;
 
-  tc::Server server;
-  std::string server_ident;
+  Context& context = Context::getContext();
+  auto& replica = context.tdb2.replica();
+  std::stringstream out;
+  bool avoid_snapshots = false;
+  bool verbose = Context::getContext().verbose("sync");
 
-  // If no server is set up, quit.
   std::string origin = Context::getContext().config.get("sync.server.origin");
   std::string url = Context::getContext().config.get("sync.server.url");
   std::string server_dir = Context::getContext().config.get("sync.local.server_dir");
-  std::string gcp_credential_path = Context::getContext().config.get("sync.gcp.credential_path");
+  std::string client_id = Context::getContext().config.get("sync.server.client_id");
+  std::string aws_bucket = Context::getContext().config.get("sync.aws.bucket");
   std::string gcp_bucket = Context::getContext().config.get("sync.gcp.bucket");
   std::string encryption_secret = Context::getContext().config.get("sync.encryption_secret");
 
   // sync.server.origin is a deprecated synonym for sync.server.url
   std::string server_url = url == "" ? origin : url;
-
-  if (server_dir != "") {
-    server = tc::Server::new_local(server_dir);
-    server_ident = server_dir;
-  } else if (gcp_bucket != "") {
-    if (encryption_secret == "") {
-      throw std::string("sync.encryption_secret is required");
-    }
-    server = tc::Server::new_gcp(gcp_bucket, gcp_credential_path, encryption_secret);
-    std::ostringstream os;
-    os << "GCP bucket " << gcp_bucket;
-    server_ident = os.str();
-  } else if (server_url != "") {
-    std::string client_id = Context::getContext().config.get("sync.server.client_id");
-    if (client_id == "" || encryption_secret == "") {
-      throw std::string("sync.server.client_id and sync.encryption_secret are required");
-    }
-    server = tc::Server::new_sync(server_url, client_id, encryption_secret);
-    std::ostringstream os;
-    os << "Sync server at " << server_url;
-    server_ident = os.str();
-  } else {
-    throw std::string("No sync.* settings are configured. See task-sync(5).");
-  }
-
-  std::stringstream out;
   if (origin != "") {
     out << "sync.server.origin is deprecated. Use sync.server.url instead.\n";
   }
 
-  if (Context::getContext().verbose("sync")) {
-    out << format("Syncing with {1}", server_ident) << '\n';
-  }
+  if (server_dir != "") {
+    if (verbose) {
+      out << format("Syncing with {1}", server_dir) << '\n';
+    }
+    replica->sync_to_local(server_dir, avoid_snapshots);
+  } else if (aws_bucket != "") {
+    std::string aws_region = Context::getContext().config.get("sync.aws.region");
+    std::string aws_profile = Context::getContext().config.get("sync.aws.profile");
+    std::string aws_access_key_id = Context::getContext().config.get("sync.aws.access_key_id");
+    std::string aws_secret_access_key =
+        Context::getContext().config.get("sync.aws.secret_access_key");
+    std::string aws_default_credentials =
+        Context::getContext().config.get("sync.aws.default_credentials");
+    if (aws_region == "") {
+      throw std::string("sync.aws.region is required");
+    }
+    if (encryption_secret == "") {
+      throw std::string("sync.encryption_secret is required");
+    }
 
-  Context& context = Context::getContext();
-  context.tdb2.sync(std::move(server), false);
+    bool using_profile = false;
+    bool using_creds = false;
+    bool using_default = false;
+    if (aws_profile != "") {
+      using_profile = true;
+    }
+    if (aws_access_key_id != "" || aws_secret_access_key != "") {
+      using_creds = true;
+    }
+    if (aws_default_credentials != "") {
+      using_default = true;
+    }
+
+    if (using_profile + using_creds + using_default != 1) {
+      throw std::string("exactly one method of specifying AWS credentials is required");
+    }
+
+    if (verbose) {
+      out << format("Syncing with AWS bucket {1}", aws_bucket) << '\n';
+    }
+
+    if (using_profile) {
+      replica->sync_to_aws_with_profile(aws_region, aws_bucket, aws_profile, encryption_secret,
+                                        avoid_snapshots);
+    } else if (using_creds) {
+      replica->sync_to_aws_with_access_key(aws_region, aws_bucket, aws_access_key_id,
+                                           aws_secret_access_key, encryption_secret,
+                                           avoid_snapshots);
+    } else {
+      replica->sync_to_aws_with_default_creds(aws_region, aws_bucket, encryption_secret,
+                                              avoid_snapshots);
+    }
+  } else if (gcp_bucket != "") {
+    std::string gcp_credential_path = Context::getContext().config.get("sync.gcp.credential_path");
+    if (encryption_secret == "") {
+      throw std::string("sync.encryption_secret is required");
+    }
+    if (verbose) {
+      out << format("Syncing with GCP bucket {1}", gcp_bucket) << '\n';
+    }
+    replica->sync_to_gcp(gcp_bucket, gcp_credential_path, encryption_secret, avoid_snapshots);
+  } else if (server_url != "") {
+    if (client_id == "" || encryption_secret == "") {
+      throw std::string("sync.server.client_id and sync.encryption_secret are required");
+    }
+    if (verbose) {
+      out << format("Syncing with sync server at {1}", server_url) << '\n';
+    }
+    replica->sync_to_remote(server_url, tc::uuid_from_string(client_id), encryption_secret,
+                            avoid_snapshots);
+  } else {
+    throw std::string("No sync.* settings are configured. See task-sync(5).");
+  }
 
   if (context.config.getBoolean("purge.on-sync")) {
     context.tdb2.expire_tasks();
